@@ -104,6 +104,8 @@ c
 c               DI-3000 routines replaced by Postscript
 c                 Tai-he Xia 27-12-93
 c               Revised version, Peter G"untert, 18-08-1994
+c               \\ changed to \ for gfortran
+c                 Peter Guentert, 13.05.2025
 c
 c     ------------------------------------------ example input data file
 c     # example file
@@ -882,7 +884,7 @@ c     *             def(jrep)(1:ldef(jrep)),'):'
         if (repres(i:i).eq.' ') repres(i:i)=repres(i-1:i-1)
         if (repres(i:i).ge.'a' .and. repres(i:i).le.'z')
      *    repres(i:i)=char(ichar(repres(i:i))+ichar('A')-ichar('a'))
-        if (index('-&.+XOSFCHV=/BRPD^EWY\\',repres(i:i)).eq.0)
+        if (index('-&.+XOSFCHV=/BRPD^EWY\',repres(i:i)).eq.0)
      *    call errmsg ('GRAF: Illegal representation type')
       end do
 c     -------------------------------------------------- set connections
@@ -998,7 +1000,7 @@ c          if (repres(i:i).eq.'D') call jlwide (5.0)
                 call jdraw (x(j)+dxmark,y(j,i-1)+y(j,i))
                 call jmove (x(j)-dxmark,y(j,i-1)-y(j,i))
                 call jdraw (x(j)+dxmark,y(j,i-1)-y(j,i))
-              else if (index('HV=/BRW\\',repres(i:i)).gt.0) then
+              else if (index('HV=/BRW\',repres(i:i)).gt.0) then
                 if (j.eq.1) then
                   x1=xmin
                 else
@@ -1045,7 +1047,7 @@ c          if (repres(i:i).eq.'D') call jlwide (5.0)
                 else if (repres(i:i).eq.'/') then
                   call hatch (x1,y1,x2,y2,
      *                        deltay/deltax/aspek,2.0*dymark)
-                else if (repres(i:i).eq.'\\') then
+                else if (repres(i:i).eq.'\') then
                   call hatch (x1,y1,x2,y2,
      *                        -deltay/deltax/aspek,2.0*dymark)
                 end if
@@ -1098,7 +1100,11 @@ c     ------------------------------------------------- draw connections
             xxprev=x(i1)
             yyprev=yy
             dxx=(x(i2)-x(i1))/200.1
-            do xx=x(i1)+dxx,x(i2),dxx
+!            do xx=x(i1)+dxx,x(i2),dxx
+            xx=x(i1)
+            do
+              xx=xx+dxx
+              if (xx.gt.x(i2)) exit
               call splint (xsplin,ysplin,ytmp,nsplin,xx,yy)
               if (yy.gt.ymax .and. yyprev.lt.ymax) then
                 call jdraw (xxprev+dxx*(ymax-yyprev)/(yy-yyprev),ymax)
@@ -1553,10 +1559,13 @@ c
       if (slope.gt.0.0) then
         bll=y1-slope*x1
         bur=y2-slope*x2
-        do b=y1-slope*x2,y2-slope*x1,deltab
+!        do b=y1-slope*x2,y2-slope*x1,deltab
+        b=y1-slope*x2
+        do
+          if (b.gt.y2-slope*x1) exit
           if (b.le.bll) then
             call jmove ((y1-b)/slope,y1)
-         else
+          else
             call jmove (x1,slope*x1+b)
           end if
           if (b.le.bur) then
@@ -1564,14 +1573,18 @@ c
           else
             call jdraw ((y2-b)/slope,y2)
           end if
+          b=b+deltab
         end do
       else
         bll=y1-slope*x2
         bur=y2-slope*x1
-        do b=y1-slope*x1,y2-slope*x2,deltab
+!        do b=y1-slope*x1,y2-slope*x2,deltab
+        b=y1-slope*x1
+        do
+          if (b.gt.y2-slope*x2) exit
           if (b.le.bll) then
             call jmove ((y1-b)/slope,y1)
-         else
+          else
             call jmove (x2,slope*x2+b)
           end if
           if (b.le.bur) then
@@ -1731,7 +1744,8 @@ c
       k=0
       m=len(str)
       oldfnt=font
-      if (str(1:1) .eq. '\\' .and. str(2:2).ne.'\\') then
+c      print *,'str=|'//trim(str)//'|'
+      if (str(1:1).eq.'\' .and. str(2:2).ne.'\') then
         do k=2,m
           if (str(k:k).le.' ') go to 20
         end do
