@@ -242,7 +242,7 @@ c       ........................... apply cutoff on relative probability
 c     --------------------------------------- map fragments individually
       print '(A)','___________________________________________________',
      *            ' ',
-     *            'MAPPER 2.0',
+     *            'MAPPER 2.1',
      *            ' ',
      *            'Copyright (c) 2002 Peter Guntert',
      *            'All rights reserved.',
@@ -617,7 +617,8 @@ c     ------------------------------------------------------------- plot
       do k=1,na
         if (k.eq.1) then
           write (1,'(A,4F10.2)')
-     *          '#VIEWPORT',-1.0,1.0,0.7-0.5*min(0.65,1.3/na),0.7
+     *          '#VIEWPORT',-1.0,1.0,0.7-0.5*min(0.65,1.3/na),0.7,
+     *          '#LETTERSIZE 0.015'
         else
           write (1,'(A)') '#NEXTPLOT'
           write (1,'(A)') '#VIEWPORT v'
